==> libsbml_5.10.0+dfsg.orig.tar.xz: libSBML-5.10.0-Source/src/sbml/packages/multi/common/multifwd.h <==
/**
 * @file:   multifwd.h
 * @brief:  Implementation of the multifwd class
 * @author: SBMLTeam
 *
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2009-2013 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 *     Pasadena, CA, USA 
 *
 * Copyright (C) 2002-2005 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. Japan Science and Technology Agency, Japan
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 * ------------------------------------------------------------------------ -->
 */
#ifndef multifwd_H
#define multifwd_H

/**
 * Forward declaration of all opaque C types.
 *
 * Declaring all types up-front avoids "redefinition of type Foo" compile
 * errors and allows our combined C/C++ headers to depend minimally upon
 * each other.  Put another way, the type definitions below serve the same
 * purpose as "class Foo;" forward declarations in C++ code.
 */

#ifdef __cplusplus
#  define CLASS_OR_STRUCT class
#else
#  define CLASS_OR_STRUCT struct
#endif  /* __cplusplus */	

LIBSBML_CPP_NAMESPACE_BEGIN

typedef CLASS_OR_STRUCT PossibleSpeciesFeatureValue    PossibleSpeciesFeatureValue_t;
typedef CLASS_OR_STRUCT SpeciesFeatureValue    SpeciesFeatureValue_t;
typedef CLASS_OR_STRUCT CompartmentReference    CompartmentReference_t;
typedef CLASS_OR_STRUCT SpeciesTypeInstance    SpeciesTypeInstance_t;
typedef CLASS_OR_STRUCT InSpeciesTypeBond    InSpeciesTypeBond_t;
typedef CLASS_OR_STRUCT DenotedSpeciesTypeComponentIndex    DenotedSpeciesTypeComponentIndex_t;
typedef CLASS_OR_STRUCT OutwardBindingSite    OutwardBindingSite_t;
typedef CLASS_OR_STRUCT SpeciesFeatureChange    SpeciesFeatureChange_t;
typedef CLASS_OR_STRUCT SpeciesFeatureType    SpeciesFeatureType_t;
typedef CLASS_OR_STRUCT SpeciesTypeComponentIndex    SpeciesTypeComponentIndex_t;
typedef CLASS_OR_STRUCT SpeciesFeature    SpeciesFeature_t;
typedef CLASS_OR_STRUCT SpeciesTypeComponentMapInProduct    SpeciesTypeComponentMapInProduct_t;
typedef CLASS_OR_STRUCT MultiSpeciesType    MultiSpeciesType_t;

LIBSBML_CPP_NAMESPACE_END

#undef CLASS_OR_STRUCT


#endif  /* multifwd_H */

==> libsbml_5.13.0+dfsg.orig.tar.xz: libSBML-5.13.0-Source/src/sbml/packages/multi/common/multifwd.h <==
/**
 * @file:   multifwd.h
 * @brief:  Implementation of the multifwd class
 * @author: SBMLTeam
 *
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2013-2016 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *     3. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2009-2013 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 *     Pasadena, CA, USA 
 *
 * Copyright (C) 2002-2005 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. Japan Science and Technology Agency, Japan
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 * ------------------------------------------------------------------------ -->
 */
#ifndef multifwd_H
#define multifwd_H

/**
 * Forward declaration of all opaque C types.
 *
 * Declaring all types up-front avoids "redefinition of type Foo" compile
 * errors and allows our combined C/C++ headers to depend minimally upon
 * each other.  Put another way, the type definitions below serve the same
 * purpose as "class Foo;" forward declarations in C++ code.
 */

#ifdef __cplusplus
#  define CLASS_OR_STRUCT class
#else
#  define CLASS_OR_STRUCT struct
#endif  /* __cplusplus */	

LIBSBML_CPP_NAMESPACE_BEGIN

typedef CLASS_OR_STRUCT PossibleSpeciesFeatureValue    PossibleSpeciesFeatureValue_t;
typedef CLASS_OR_STRUCT SpeciesFeatureValue    SpeciesFeatureValue_t;
typedef CLASS_OR_STRUCT CompartmentReference    CompartmentReference_t;
typedef CLASS_OR_STRUCT SpeciesTypeInstance    SpeciesTypeInstance_t;
typedef CLASS_OR_STRUCT InSpeciesTypeBond    InSpeciesTypeBond_t;
typedef CLASS_OR_STRUCT OutwardBindingSite    OutwardBindingSite_t;
typedef CLASS_OR_STRUCT SpeciesFeatureChange    SpeciesFeatureChange_t;
typedef CLASS_OR_STRUCT SpeciesFeatureType    SpeciesFeatureType_t;
typedef CLASS_OR_STRUCT SpeciesTypeComponentIndex    SpeciesTypeComponentIndex_t;
typedef CLASS_OR_STRUCT SpeciesFeature    SpeciesFeature_t;
typedef CLASS_OR_STRUCT SpeciesTypeComponentMapInProduct    SpeciesTypeComponentMapInProduct_t;
typedef CLASS_OR_STRUCT MultiSpeciesType    MultiSpeciesType_t;
typedef CLASS_OR_STRUCT BindingSiteSpeciesType    BindingSiteSpeciesType_t;
typedef CLASS_OR_STRUCT IntraSpeciesReaction    IntraSpeciesReaction_t;

LIBSBML_CPP_NAMESPACE_END

#undef CLASS_OR_STRUCT


#endif  /* multifwd_H */
